@@ -68,13 +68,16 @@ async def _op(model, op, reqtype, delete=False, **kwargs):
 
     req = reqtype()
     for k, v in kwargs.items():
+        f = reqtype.DESCRIPTOR.fields_by_name[k]
         if v is None and not (f.message_type and f.message_type.name.startswith('Nullable')):
             continue  # allow args to be passed a None to avoid setting them.
-        f = reqtype.DESCRIPTOR.fields_by_name[k]
         if f.message_type:  # this is a nested message, not a simple type
             if f.message_type.name.startswith('Nullable'):
                 # special case where we have a OneOf for optional values
-                setattr(getattr(req, k), 'data', v)
+                if v is None:
+                    setattr(getattr(req, k), 'null', 0) # NullValue.NULL_VALUE
+                else:
+                    setattr(getattr(req, k), 'data', v)
             else:
                 if isinstance(v, list):
                     for x in v:
